@@ -89,15 +89,17 @@ ephy_profile_utils_set_migration_version (int version)
 #define EPHY_PROFILE_MIGRATOR "ephy-profile-migrator"
 
 gboolean
-ephy_profile_utils_do_migration (const char *profile_directory, int test_to_run, gboolean debug)
+ephy_profile_utils_do_migration (const char *profile_directory,
+                                 int         test_to_run,
+                                 gboolean    debug)
 {
-  g_autoptr(GError) error = NULL;
+  g_autoptr (GError) error = NULL;
   g_autofree char *index = NULL;
   g_autofree char *version = NULL;
   int status;
   const char *argv[8] = { PKGLIBEXECDIR "/" EPHY_PROFILE_MIGRATOR, "-v" };
   int i = 2; /* index for argv, start filling at 2. */
-  g_auto(GStrv) envp = NULL;
+  g_auto (GStrv) envp = NULL;
 
   envp = g_environ_setenv (g_get_environ (),
                            "EPHY_LOG_MODULES", "ephy-profile",
@@ -106,7 +108,7 @@ ephy_profile_utils_do_migration (const char *profile_directory, int test_to_run,
   argv[i++] = version = g_strdup_printf ("%d", EPHY_PROFILE_MIGRATION_VERSION);
 
   /* If we're not trying to run a migration step in a test and there
-     is nothing to migrate, don't spawn the migrator at all. */
+   *  is nothing to migrate, don't spawn the migrator at all. */
   if (test_to_run == -1 &&
       EPHY_PROFILE_MIGRATION_VERSION == ephy_profile_utils_get_migration_version ()) {
     return TRUE;
