@@ -30,6 +30,7 @@
 #include "ephy-embed-utils.h"
 #include "ephy-file-chooser.h"
 #include "ephy-file-helpers.h"
+#include "ephy-filters-manager.h"
 #include "ephy-flatpak-utils.h"
 #include "ephy-gui.h"
 #include "ephy-langs.h"
@@ -43,7 +44,6 @@
 #include "ephy-sync-service.h"
 #include "ephy-sync-utils.h"
 #include "ephy-time-helpers.h"
-#include "ephy-uri-tester-shared.h"
 #include "ephy-web-app-utils.h"
 #include "clear-data-dialog.h"
 #include "cookies-dialog.h"
@@ -119,8 +119,6 @@ struct _PrefsDialog {
   GtkWidget *no_third_party;
   GtkWidget *never;
   GtkWidget *remember_passwords_switch;
-  GtkWidget *do_not_track_row;
-  GtkWidget *do_not_track_switch;
   GtkWidget *clear_personal_data_button;
 
   /* language */
@@ -567,20 +565,20 @@ sync_setup_firefox_iframe (PrefsDialog *dialog)
 
   if (!dialog->fxa_web_view) {
     script =
-             /* Handle sign-in messages from the FxA content server. */
-             "function handleToChromeMessage(event) {"
-             "  let e = JSON.stringify({type: event.type, detail: event.detail});"
-             "  window.webkit.messageHandlers.toChromeMessageHandler.postMessage(e);"
-             "};"
-             "window.addEventListener('WebChannelMessageToChrome', handleToChromeMessage);"
-             /* Handle open-webmail click event. */
-             "function handleOpenWebmailClick(event) {"
-             "  if (event.target.id == 'open-webmail' && event.target.hasAttribute('href'))"
-             "    window.webkit.messageHandlers.openWebmailClickHandler.postMessage(event.target.getAttribute('href'));"
-             "};"
-             "var stage = document.getElementById('stage');"
-             "if (stage)"
-             "  stage.addEventListener('click', handleOpenWebmailClick);";
+      /* Handle sign-in messages from the FxA content server. */
+      "function handleToChromeMessage(event) {"
+      "  let e = JSON.stringify({type: event.type, detail: event.detail});"
+      "  window.webkit.messageHandlers.toChromeMessageHandler.postMessage(e);"
+      "};"
+      "window.addEventListener('WebChannelMessageToChrome', handleToChromeMessage);"
+      /* Handle open-webmail click event. */
+      "function handleOpenWebmailClick(event) {"
+      "  if (event.target.id == 'open-webmail' && event.target.hasAttribute('href'))"
+      "    window.webkit.messageHandlers.openWebmailClickHandler.postMessage(event.target.getAttribute('href'));"
+      "};"
+      "var stage = document.getElementById('stage');"
+      "if (stage)"
+      "  stage.addEventListener('click', handleOpenWebmailClick);";
 
     dialog->fxa_script = webkit_user_script_new (script,
                                                  WEBKIT_USER_CONTENT_INJECT_TOP_FRAME,
@@ -898,7 +896,7 @@ on_manage_passwords_button_clicked (GtkWidget   *button,
   EphyPasswordsDialog *passwords_dialog;
   EphyPasswordManager *password_manager;
 
-  password_manager = ephy_embed_shell_get_password_manager (EPHY_EMBED_SHELL(ephy_shell_get_default ()));
+  password_manager = ephy_embed_shell_get_password_manager (EPHY_EMBED_SHELL (ephy_shell_get_default ()));
   passwords_dialog = ephy_passwords_dialog_new (password_manager);
 
   gtk_window_set_transient_for (GTK_WINDOW (passwords_dialog), GTK_WINDOW (dialog));
@@ -944,7 +942,7 @@ on_default_zoom_spin_button_value_changed (GtkSpinButton *spin,
 
   adjustment = gtk_spin_button_get_adjustment (spin);
   value = gtk_adjustment_get_value (adjustment);
-  value = roundf(value) / 100;
+  value = roundf (value) / 100;
   g_settings_set_double (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_DEFAULT_ZOOM_LEVEL, value);
 }
 
@@ -1003,8 +1001,6 @@ prefs_dialog_class_init (PrefsDialogClass *klass)
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, no_third_party);
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, never);
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, remember_passwords_switch);
-  gtk_widget_class_bind_template_child (widget_class, PrefsDialog, do_not_track_row);
-  gtk_widget_class_bind_template_child (widget_class, PrefsDialog, do_not_track_switch);
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, clear_personal_data_button);
 
   /* language */
@@ -1298,7 +1294,7 @@ setup_add_language_dialog (PrefsDialog *dialog)
   GtkTreeIter iter;
   guint i, n;
   GtkBuilder *builder;
-  g_auto(GStrv) locales;
+  g_auto (GStrv) locales;
 
   builder = gtk_builder_new_from_resource ("/org/gnome/epiphany/gtk/prefs-lang-dialog.ui");
   ad = GTK_WIDGET (gtk_builder_get_object (builder, "add_language_dialog"));
@@ -1493,6 +1489,38 @@ language_editor_selection_changed_cb (GtkTreeSelection *selection,
   language_editor_update_buttons (dialog);
 }
 
+static char *
+normalize_locale (const char *locale)
+{
+  char *result = g_strdup (locale);
+
+  /* The result we store in prefs looks like es-ES or en-US. We don't
+   * store codeset (not used in Accept-Langs) and we store with hyphen
+   * instead of underscore (ditto). So here we just uppercase the
+   * country code, converting e.g. es-es to es-ES. We have to do this
+   * because older versions of Epiphany stored locales as entirely
+   * lowercase.
+   */
+  for (char *p = strchr (result, '-'); p != NULL && *p != '\0'; p++)
+    *p = g_ascii_toupper (*p);
+
+  return result;
+}
+
+static char *
+language_for_locale (const char *locale)
+{
+  g_autoptr (GString) string = g_string_new (locale);
+
+  /* Before calling gnome_get_language_from_locale() we have to convert
+   * from web locales (e.g. es-ES) to UNIX (e.g. es_ES.UTF-8).
+   */
+  g_strdelimit (string->str, "-", '_');
+  g_string_append (string, ".UTF-8");
+
+  return gnome_get_language_from_locale (string->str, string->str);
+}
+
 static void
 create_language_section (PrefsDialog *dialog)
 {
@@ -1553,9 +1581,9 @@ create_language_section (PrefsDialog *dialog)
     if (strcmp (code, "system") == 0) {
       add_system_language_entry (store);
     } else if (code[0] != '\0') {
-      g_autofree char *normalized_locale = ephy_langs_normalize_locale (code);
+      g_autofree char *normalized_locale = normalize_locale (code);
       if (normalized_locale != NULL) {
-        g_autofree char *language_name = ephy_langs_language_for_locale (normalized_locale);
+        g_autofree char *language_name = language_for_locale (normalized_locale);
         if (language_name == NULL)
           language_name = g_strdup (normalized_locale);
         language_editor_add (dialog, normalized_locale, language_name);
@@ -1639,24 +1667,6 @@ prefs_dialog_response_cb (GtkWidget   *widget,
   gtk_widget_destroy (widget);
 }
 
-static void
-do_not_track_switch_activated_cb (GtkWidget   *sw,
-                                  PrefsDialog *dialog)
-{
-  char **filters;
-  char **new_filters;
-
-  filters = g_settings_get_strv (EPHY_SETTINGS_MAIN, EPHY_PREFS_ADBLOCK_FILTERS);
-  if (gtk_switch_get_active (GTK_SWITCH (sw)))
-    new_filters = ephy_strv_append ((const char * const *)filters, ADBLOCK_PRIVACY_FILTER_URL);
-  else
-    new_filters = ephy_strv_remove ((const char * const *)filters, ADBLOCK_PRIVACY_FILTER_URL);
-  g_settings_set_strv (EPHY_SETTINGS_MAIN, EPHY_PREFS_ADBLOCK_FILTERS, (const char * const *)new_filters);
-
-  g_strfreev (filters);
-  g_strfreev (new_filters);
-}
-
 static void
 clear_personal_data_button_clicked_cb (GtkWidget   *button,
                                        PrefsDialog *dialog)
@@ -1678,7 +1688,7 @@ sync_frequency_get_mapping (GValue   *value,
 {
   uint minutes = g_variant_get_uint32 (variant);
 
-  for (gint i = 0; i < (gint) G_N_ELEMENTS (sync_frequency_minutes); i++) {
+  for (gint i = 0; i < (gint)G_N_ELEMENTS (sync_frequency_minutes); i++) {
     if (sync_frequency_minutes[i] != minutes)
       continue;
 
@@ -1697,7 +1707,7 @@ sync_frequency_set_mapping (const GValue       *value,
 {
   gint i = g_value_get_int (value);
 
-  if (i >= (gint) G_N_ELEMENTS (sync_frequency_minutes))
+  if (i >= (gint)G_N_ELEMENTS (sync_frequency_minutes))
     return NULL;
 
   return g_variant_new_uint32 (sync_frequency_minutes[i]);
@@ -1785,7 +1795,7 @@ blank_homepage_get_mapping (GValue   *value,
 
   setting = g_variant_get_string (variant, NULL);
   if (g_strcmp0 (setting, "about:blank") == 0)
-      g_value_set_boolean (value, TRUE);
+    g_value_set_boolean (value, TRUE);
 
   return TRUE;
 }
@@ -1859,8 +1869,8 @@ custom_homepage_entry_changed (GtkEntry    *entry,
 }
 
 static void
-custom_homepage_entry_icon_released (GtkEntry            *entry,
-                                     GtkEntryIconPosition icon_pos)
+custom_homepage_entry_icon_released (GtkEntry             *entry,
+                                     GtkEntryIconPosition  icon_pos)
 {
   if (icon_pos == GTK_ENTRY_ICON_SECONDARY)
     gtk_entry_set_text (entry, "");
@@ -1971,22 +1981,7 @@ setup_general_page (PrefsDialog *dialog)
                    dialog->adblock_allow_switch,
                    "active",
                    G_SETTINGS_BIND_DEFAULT);
-  g_settings_bind (web_settings,
-                   EPHY_PREFS_WEB_ENABLE_ADBLOCK,
-                   dialog->do_not_track_row,
-                   "sensitive",
-                   G_SETTINGS_BIND_DEFAULT);
 
-  g_settings_bind (web_settings,
-                   EPHY_PREFS_WEB_DO_NOT_TRACK,
-                   dialog->do_not_track_switch,
-                   "active",
-                   /* Teensy hack: don't override the previous binding. */
-                   G_SETTINGS_BIND_NO_SENSITIVITY);
-  g_signal_connect (dialog->do_not_track_switch,
-                    "notify::active",
-                    G_CALLBACK (do_not_track_switch_activated_cb),
-                    dialog);
   g_settings_bind (web_settings,
                    EPHY_PREFS_WEB_ENABLE_SMOOTH_SCROLLING,
                    dialog->enable_smooth_scrolling_switch,
@@ -2028,12 +2023,12 @@ reader_font_style_get_name (HdyEnumValueObject *value,
   g_assert (HDY_IS_ENUM_VALUE_OBJECT (value));
 
   switch (hdy_enum_value_object_get_value (value)) {
-  case EPHY_PREFS_READER_FONT_STYLE_SANS:
-    return g_strdup (N_("Sans"));
-  case EPHY_PREFS_READER_FONT_STYLE_SERIF:
-    return g_strdup (N_("Serif"));
-  default:
-    return NULL;
+    case EPHY_PREFS_READER_FONT_STYLE_SANS:
+      return g_strdup (N_("Sans"));
+    case EPHY_PREFS_READER_FONT_STYLE_SERIF:
+      return g_strdup (N_("Serif"));
+    default:
+      return NULL;
   }
 }
 
@@ -2058,12 +2053,12 @@ reader_font_style_set_mapping (const GValue       *value,
                                gpointer            user_data)
 {
   switch (g_value_get_int (value)) {
-  case EPHY_PREFS_READER_FONT_STYLE_SANS:
-    return g_variant_new_string ("sans");
-  case EPHY_PREFS_READER_FONT_STYLE_SERIF:
-    return g_variant_new_string ("serif");
-  default:
-    return g_variant_new_string ("crashed");
+    case EPHY_PREFS_READER_FONT_STYLE_SANS:
+      return g_variant_new_string ("sans");
+    case EPHY_PREFS_READER_FONT_STYLE_SERIF:
+      return g_variant_new_string ("serif");
+    default:
+      return g_variant_new_string ("crashed");
   }
 }
 
@@ -2074,12 +2069,12 @@ reader_color_scheme_get_name (HdyEnumValueObject *value,
   g_assert (HDY_IS_ENUM_VALUE_OBJECT (value));
 
   switch (hdy_enum_value_object_get_value (value)) {
-  case EPHY_PREFS_READER_COLORS_LIGHT:
-    return g_strdup (N_("Light"));
-  case EPHY_PREFS_READER_COLORS_DARK:
-    return g_strdup (N_("Dark"));
-  default:
-    return NULL;
+    case EPHY_PREFS_READER_COLORS_LIGHT:
+      return g_strdup (N_("Light"));
+    case EPHY_PREFS_READER_COLORS_DARK:
+      return g_strdup (N_("Dark"));
+    default:
+      return NULL;
   }
 }
 
@@ -2104,12 +2099,12 @@ reader_color_scheme_set_mapping (const GValue       *value,
                                  gpointer            user_data)
 {
   switch (g_value_get_int (value)) {
-  case EPHY_PREFS_READER_COLORS_LIGHT:
-    return g_variant_new_string ("light");
-  case EPHY_PREFS_READER_COLORS_DARK:
-    return g_variant_new_string ("dark");
-  default:
-    return g_variant_new_string ("crashed");
+    case EPHY_PREFS_READER_COLORS_LIGHT:
+      return g_variant_new_string ("light");
+    case EPHY_PREFS_READER_COLORS_DARK:
+      return g_variant_new_string ("dark");
+    default:
+      return g_variant_new_string ("crashed");
   }
 }
 
@@ -2254,7 +2249,7 @@ create_sync_frequency_minutes_model ()
 {
   GListStore *list_store = g_list_store_new (HDY_TYPE_VALUE_OBJECT);
   HdyValueObject *obj;
-  g_auto(GValue) value = G_VALUE_INIT;
+  g_auto (GValue) value = G_VALUE_INIT;
   guint i;
 
   g_value_init (&value, G_TYPE_UINT);
@@ -2282,7 +2277,7 @@ setup_sync_page (PrefsDialog *dialog)
   GSettings *sync_settings = ephy_settings_get (EPHY_PREFS_SYNC_SCHEMA);
   char *user = ephy_sync_utils_get_sync_user ();
   char *name = ephy_sync_utils_get_device_name ();
-  g_autoptr(GListModel) sync_frequency_minutes_model = create_sync_frequency_minutes_model ();
+  g_autoptr (GListModel) sync_frequency_minutes_model = create_sync_frequency_minutes_model ();
 
   gtk_entry_set_text (GTK_ENTRY (dialog->sync_device_name_entry), name);
 
@@ -2319,7 +2314,7 @@ setup_sync_page (PrefsDialog *dialog)
 
   hdy_combo_row_bind_name_model (HDY_COMBO_ROW (dialog->sync_frequency_row),
                                  sync_frequency_minutes_model,
-                                 (HdyComboRowGetNameFunc) get_sync_frequency_minutes_name,
+                                 (HdyComboRowGetNameFunc)get_sync_frequency_minutes_name,
                                  NULL,
                                  NULL);
   g_settings_bind_with_mapping (sync_settings,
@@ -2379,12 +2374,6 @@ prefs_dialog_init (PrefsDialog *dialog)
                           mode != EPHY_EMBED_SHELL_MODE_APPLICATION);
   gtk_widget_set_visible (dialog->browsing_box,
                           mode != EPHY_EMBED_SHELL_MODE_APPLICATION);
-  gtk_widget_set_visible (dialog->do_not_track_switch,
-                          mode != EPHY_EMBED_SHELL_MODE_APPLICATION);
-  gtk_widget_set_visible (dialog->enable_smooth_scrolling_switch,
-                          mode != EPHY_EMBED_SHELL_MODE_APPLICATION);
-  gtk_widget_set_visible (dialog->enable_mouse_gesture_switch,
-                          mode != EPHY_EMBED_SHELL_MODE_APPLICATION);
   gtk_widget_set_visible (dialog->reader_mode_box,
                           mode != EPHY_EMBED_SHELL_MODE_APPLICATION);
 
