@@ -23,6 +23,7 @@
 #include "ephy-bookmarks-manager.h"
 #include "ephy-debug.h"
 #include "ephy-file-helpers.h"
+#include "ephy-filters-manager.h"
 #include "ephy-history-service.h"
 #include "ephy-password-manager.h"
 #include "ephy-prefs.h"
@@ -33,7 +34,6 @@
 #include "ephy-string.h"
 #include "ephy-sync-debug.h"
 #include "ephy-sync-utils.h"
-#include "ephy-uri-tester-shared.h"
 #include "ephy-web-app-utils.h"
 #include "gvdb-builder.h"
 #include "gvdb-reader.h"
@@ -73,28 +73,18 @@ static const char *
 legacy_profile_dir (void)
 {
   static char *dir = NULL;
-  if (dir == NULL)
-    {
-      /* FIXME: This is fragile and not correct.
-       */
-      if (profile_dir != NULL)
-        {
-          dir = profile_dir;
-        }
-      else
-        {
-          dir = (char *)legacy_default_profile_dir ();
-        }
+  if (dir == NULL) {
+    /* FIXME: This is fragile and not correct.
+     */
+    if (profile_dir != NULL) {
+      dir = profile_dir;
+    } else {
+      dir = (char *)legacy_default_profile_dir ();
     }
+  }
   return dir;
 }
 
-static gboolean
-legacy_dir_is_default (void)
-{
-  return !strcmp (legacy_profile_dir (), legacy_default_profile_dir ());
-}
-
 /*
  * What to do to add new migration steps:
  *  - Bump EPHY_PROFILE_MIGRATION_VERSION in lib/ephy-profile-utils.h
@@ -408,83 +398,6 @@ out:
   g_free (filename);
 }
 
-static void
-migrate_adblock_filters (void)
-{
-  char *adblock_dir;
-  char *filters_filename;
-  char *contents;
-  gsize content_size;
-  GPtrArray *filters_array = NULL;
-  GError *error = NULL;
-
-  adblock_dir = g_build_filename (legacy_profile_dir (), "adblock", NULL);
-  if (!g_file_test (adblock_dir, G_FILE_TEST_IS_DIR)) {
-    g_free (adblock_dir);
-    return;
-  }
-
-  if (!legacy_dir_is_default ()) {
-    /* Adblock filters rules are now shared to save space */
-    ephy_file_delete_dir_recursively (adblock_dir, NULL);
-    g_free (adblock_dir);
-
-    adblock_dir = g_build_filename (legacy_default_profile_dir (), "adblock", NULL);
-  }
-
-  filters_filename = g_build_filename (adblock_dir, "filters.list", NULL);
-  g_free (adblock_dir);
-
-  if (!g_file_get_contents (filters_filename, &contents, &content_size, &error)) {
-    if (!g_error_matches (error, G_FILE_ERROR, G_FILE_ERROR_NOENT))
-      g_warning ("Failed to read filters file: %s: %s", filters_filename, error->message);
-    g_free (filters_filename);
-    g_error_free (error);
-    return;
-  }
-
-  if (content_size > 0) {
-    char **filter_list;
-    guint  filter_list_length;
-    guint  i;
-
-    filter_list = g_strsplit (contents, ";", -1);
-    filter_list_length = g_strv_length (filter_list);
-    if (filter_list_length > 0) {
-      filters_array = g_ptr_array_sized_new (MAX (2, filter_list_length) + 1);
-      g_ptr_array_set_free_func (filters_array, g_free);
-      g_ptr_array_add (filters_array, g_strdup (ADBLOCK_DEFAULT_FILTER_URL));
-
-      for (i = 0; filter_list[i]; i++) {
-        char *url;
-
-        url = g_strstrip (filter_list[i]);
-        if (url[0] != '\0' && strcmp (url, ADBLOCK_DEFAULT_FILTER_URL))
-          g_ptr_array_add (filters_array, g_strdup (url));
-      }
-
-      if (filters_array->len == 1) {
-        /* No additional filters, so do nothing. */
-        g_ptr_array_free (filters_array, TRUE);
-        filters_array = NULL;
-      } else {
-        g_ptr_array_add (filters_array, NULL);
-      }
-    }
-    g_strfreev (filter_list);
-  }
-
-  if (filters_array) {
-    g_settings_set_strv (EPHY_SETTINGS_MAIN,
-                         EPHY_PREFS_ADBLOCK_FILTERS,
-                         (const gchar * const *)filters_array->pdata);
-    g_settings_sync ();
-    g_ptr_array_free (filters_array, TRUE);
-  }
-
-  g_unlink (filters_filename);
-}
-
 static void
 migrate_initial_state (void)
 {
@@ -714,7 +627,7 @@ migrate_passwords_add_target_origin (void)
     /* In most cases target_origin has the same value as origin
      * We don't have a way of figuring out the correct value retroactively,
      * so just use the origin value.
-    */
+     */
     if (target_origin == NULL)
       g_hash_table_insert (attrs, g_strdup (TARGET_ORIGIN_KEY), g_strdup (origin));
 
@@ -964,7 +877,7 @@ migrate_passwords_timestamp (void)
 
     timestamp_d = g_ascii_strtod (timestamp, NULL);
     timestamp_i = (gint64)ceil (timestamp_d);
-    g_hash_table_insert (attrs, g_strdup (SERVER_TIME_MODIFIED_KEY), g_strdup_printf ("%"PRId64, timestamp_i));
+    g_hash_table_insert (attrs, g_strdup (SERVER_TIME_MODIFIED_KEY), g_strdup_printf ("%" PRId64, timestamp_i));
 
     if (username)
       label = g_strdup_printf ("Password for %s in a form in %s", username, origin);
@@ -992,28 +905,6 @@ out:
   g_list_free_full (passwords, g_object_unref);
 }
 
-static void
-migrate_annoyance_list (void)
-{
-  GVariant *user_value;
-  const char **filters;
-  char **modified_filters;
-
-  /* Has the filters setting been modified? If not, we're done. */
-  user_value = g_settings_get_user_value (EPHY_SETTINGS_MAIN, EPHY_PREFS_ADBLOCK_FILTERS);
-  if (!user_value)
-    return;
-
-  /* The annoyance list was causing a bunch of problems. Forcibly remove it. */
-  filters = g_variant_get_strv (user_value, NULL);
-  modified_filters = ephy_strv_remove (filters, "https://easylist.to/easylist/fanboy-annoyance.txt");
-  g_settings_set_strv (EPHY_SETTINGS_MAIN, EPHY_PREFS_ADBLOCK_FILTERS, (const char * const *)modified_filters);
-
-  g_variant_unref (user_value);
-  g_free (filters);
-  g_strfreev (modified_filters);
-}
-
 static void
 migrate_zoom_level (void)
 {
@@ -1105,10 +996,10 @@ static gboolean
 move_directory_contents (const char *source_path,
                          const char *dest_path)
 {
-  g_autoptr(GFile) source = g_file_new_for_path (source_path);
-  g_autoptr(GFile) dest = g_file_new_for_path (dest_path);
-  g_autoptr(GFileEnumerator) direnum = NULL;
-  g_autoptr(GError) error = NULL;
+  g_autoptr (GFile) source = g_file_new_for_path (source_path);
+  g_autoptr (GFile) dest = g_file_new_for_path (dest_path);
+  g_autoptr (GFileEnumerator) direnum = NULL;
+  g_autoptr (GError) error = NULL;
 
   /* Just a sanity check as it should already exist */
   g_file_make_directory (dest, NULL, NULL);
@@ -1123,9 +1014,9 @@ move_directory_contents (const char *source_path,
 
   while (TRUE) {
     GFileInfo *info;
-    g_autoptr(GError) error = NULL;
-    g_autoptr(GFile) source_file = NULL;
-    g_autoptr(GFile) dest_file = NULL;
+    g_autoptr (GError) error = NULL;
+    g_autoptr (GFile) source_file = NULL;
+    g_autoptr (GFile) dest_file = NULL;
 
     if (!g_file_enumerator_iterate (direnum, &info, NULL, NULL, &error)) {
       g_warning ("Failed to enumerate dir: %s", error->message);
@@ -1163,10 +1054,10 @@ migrate_webapps_harder (void)
    * contained this bug. But now migrate_profile_directories() has to be run
    * later to correct a different bug in earlier versions.
    */
-  g_autoptr(GFileEnumerator) children = NULL;
-  g_autoptr(GFileInfo) info;
+  g_autoptr (GFileEnumerator) children = NULL;
+  g_autoptr (GFileInfo) info;
   g_autofree char *parent_directory_path = NULL;
-  g_autoptr(GFile) parent_directory = NULL;
+  g_autoptr (GFile) parent_directory = NULL;
 
   parent_directory_path = g_build_filename (g_get_user_data_dir (), "epiphany", NULL);
 
@@ -1187,8 +1078,8 @@ migrate_webapps_harder (void)
       g_autofree char *app_file = g_build_filename (incorrect_profile_dir, ".app", NULL);
 
       if (g_file_test (app_file, G_FILE_TEST_EXISTS)) {
-        g_autoptr(GKeyFile) file = g_key_file_new ();
-        g_autoptr(GFile) desktop_symlink = NULL;
+        g_autoptr (GKeyFile) file = g_key_file_new ();
+        g_autoptr (GFile) desktop_symlink = NULL;
         g_autofree char *desktop_file_name = g_strconcat (name, ".desktop", NULL);
         g_autofree char *desktop_file_path = g_build_filename (correct_profile_dir, desktop_file_name, NULL);
         g_autofree char *exec = NULL;
@@ -1196,11 +1087,11 @@ migrate_webapps_harder (void)
         g_autofree char *icon = NULL;
         g_autofree char *new_icon = NULL;
         g_autofree char *desktop_symlink_path = NULL;
-        g_autoptr(GError) error = NULL;
+        g_autoptr (GError) error = NULL;
 
         move_directory_contents (incorrect_profile_dir, correct_profile_dir);
 
-        // Update Exec and Icon to point to the new profile dir
+        /* Update Exec and Icon to point to the new profile dir */
         g_key_file_load_from_file (file, desktop_file_path, G_KEY_FILE_NONE, NULL);
 
         exec = g_key_file_get_string (file, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_EXEC, &error);
@@ -1230,7 +1121,7 @@ migrate_webapps_harder (void)
         desktop_symlink = g_file_new_for_path (desktop_symlink_path);
         LOG ("Symlinking %s to %s", desktop_symlink_path, desktop_file_path);
 
-        // Try removing old symlink, failure is ok assuming it doesn't exist.
+        /* Try removing old symlink, failure is ok assuming it doesn't exist. */
         if (!g_file_delete (desktop_symlink, NULL, &error)) {
           g_warning ("Failed to remove old symbolic link: %s", error->message);
           g_clear_error (&error);
@@ -1249,10 +1140,10 @@ migrate_webapps_harder (void)
 static void
 migrate_profile_directories (void)
 {
-  g_autoptr(GFile) new_directory = NULL;
-  g_autoptr(GFile) adblock_directory = NULL;
-  g_autoptr(GFile) gsb_file = NULL;
-  g_autoptr(GFile) gsb_journal_file = NULL;
+  g_autoptr (GFile) new_directory = NULL;
+  g_autoptr (GFile) adblock_directory = NULL;
+  g_autoptr (GFile) gsb_file = NULL;
+  g_autoptr (GFile) gsb_journal_file = NULL;
   GList *web_apps;
   GList *l;
 
@@ -1263,9 +1154,9 @@ migrate_profile_directories (void)
   web_apps = ephy_web_application_get_legacy_application_list ();
   for (l = web_apps; l; l = l->next) {
     EphyWebApplication *app = (EphyWebApplication *)l->data;
-    g_autoptr(GError) error = NULL;
-    g_autoptr(GKeyFile) file = NULL;
-    g_autoptr(GFile) desktop_symlink = NULL;
+    g_autoptr (GError) error = NULL;
+    g_autoptr (GKeyFile) file = NULL;
+    g_autoptr (GFile) desktop_symlink = NULL;
     g_autofree char *old_name = g_strconcat ("app-epiphany-", app->id, NULL);
     g_autofree char *old_path = g_build_filename (legacy_default_profile_dir (), old_name, NULL);
     g_autofree char *app_path = ephy_web_application_get_profile_directory (app->id);
@@ -1283,15 +1174,15 @@ migrate_profile_directories (void)
     if (!move_directory_contents (old_path, app_path))
       continue;
 
-    // Create an empty file to indicate it's an app
+    /* Create an empty file to indicate it's an app */
     app_file = g_build_filename (app_path, ".app", NULL);
-    fd = g_open (app_file, O_WRONLY|O_CREAT|O_TRUNC, 0644);
+    fd = g_open (app_file, O_WRONLY | O_CREAT | O_TRUNC, 0644);
     if (fd < 0)
       g_warning ("Failed to create .app file: %s", g_strerror (errno));
     else
       close (fd);
 
-    // Update Exec and Icon to point to the new profile dir
+    /* Update Exec and Icon to point to the new profile dir */
     old_profile_prefix = g_build_filename (legacy_default_profile_dir (), "app-epiphany-", NULL);
     new_profile_prefix = g_build_filename (g_get_user_data_dir (), "epiphany-", NULL);
     file = g_key_file_new ();
@@ -1326,7 +1217,7 @@ migrate_profile_directories (void)
     desktop_symlink = g_file_new_for_path (desktop_symlink_path);
     LOG ("Symlinking %s to %s", desktop_symlink_path, desktop_file_path);
 
-    // Try removing old symlink, failure is ok assuming it doesn't exist.
+    /* Try removing old symlink, failure is ok assuming it doesn't exist. */
     if (!g_file_delete (desktop_symlink, NULL, &error)) {
       g_warning ("Failed to remove old symbolic link: %s", error->message);
       g_clear_error (&error);
@@ -1357,6 +1248,25 @@ migrate_profile_directories (void)
   g_file_delete (gsb_journal_file, NULL, NULL);
 }
 
+static void
+migrate_adblock_to_content_filters (void)
+{
+  /*
+   * Switching from the ABP-format rule sets to the JSON ones is done by
+   * completely removing the adblock/ subdirectory. During startup Epiphany
+   * will read the new setting and download the new filtering rules itself.
+   */
+  g_autofree char *directory = g_build_filename (ephy_cache_dir (), "adblock", NULL);
+
+  g_autoptr (GError) error = NULL;
+  if (!ephy_file_delete_dir_recursively (directory, &error) &&
+      !g_error_matches (error, G_FILE_ERROR, G_FILE_ERROR_NOENT))
+    g_warning ("Cannot delete adblock directory %s: %s", directory, error->message);
+
+  /* Remove the old key, to save a little space in the dconf store. */
+  g_settings_reset (EPHY_SETTINGS_MAIN, "adblock-filters");
+}
+
 static void
 migrate_nothing (void)
 {
@@ -1371,7 +1281,8 @@ migrate_nothing (void)
 /* If adding anything here, you need to edit EPHY_PROFILE_MIGRATION_VERSION
  * in ephy-profile-utils.h. */
 const EphyProfileMigrator migrators[] = {
-  /*  1 */ migrate_nothing,
+  /*  1 */
+  migrate_nothing,
   /*  2 */ migrate_nothing,
   /*  3 */ migrate_nothing,
   /*  4 */ migrate_nothing,
@@ -1383,7 +1294,7 @@ const EphyProfileMigrator migrators[] = {
   /* 10 */ migrate_nothing,
   /* 11 */ migrate_insecure_passwords,
   /* 12 */ migrate_bookmarks,
-  /* 13 */ migrate_adblock_filters,
+  /* 13 */ migrate_nothing,
   /* 14 */ migrate_initial_state,
   /* 15 */ migrate_permissions,
   /* 16 */ migrate_nothing,
@@ -1398,11 +1309,12 @@ const EphyProfileMigrator migrators[] = {
   /* 25 */ migrate_passwords_timestamp,
   /* 26 */ migrate_nothing,
   /* 27 */ migrate_nothing,
-  /* 28 */ migrate_annoyance_list,
+  /* 28 */ migrate_nothing,
   /* 29 */ migrate_zoom_level,
   /* 30 */ migrate_profile_directories,
   /* 31 */ migrate_web_extension_config_dir,
   /* 32 */ migrate_webapps_harder,
+  /* 33 */ migrate_adblock_to_content_filters,
 };
 
 static gboolean
@@ -1467,8 +1379,7 @@ ephy_migrator (void)
   return TRUE;
 }
 
-static const GOptionEntry option_entries[] =
-{
+static const GOptionEntry option_entries[] = {
   { "do-step", 'd', 0, G_OPTION_ARG_INT, &do_step_n,
     N_("Executes only the n-th migration step"), NULL },
   { "version", 'v', 0, G_OPTION_ARG_INT, &migration_version,
@@ -1479,7 +1390,8 @@ static const GOptionEntry option_entries[] =
 };
 
 int
-main (int argc, char *argv[])
+main (int   argc,
+      char *argv[])
 {
   GOptionContext *option_context;
   GOptionGroup *option_group;
